@@ -4,11 +4,11 @@
 // - portable-atomic https://github.com/taiki-e/portable-atomic
 //
 // Generated asm:
-// - riscv64gc https://godbolt.org/z/xfY4rM6z4
+// - riscv64gc https://godbolt.org/z/Ef9so3M8G
 
 use core::{arch::asm, mem::MaybeUninit, sync::atomic::Ordering};
 
-#[cfg(any(target_feature_a, target_feature = "a"))]
+#[cfg(any(target_feature = "a", atomic_maybe_uninit_target_feature_a))]
 use crate::raw::AtomicSwap;
 use crate::raw::{AtomicLoad, AtomicStore};
 
@@ -65,7 +65,7 @@ macro_rules! atomic_load_store {
                                 options(nostack),
                             );
                         }
-                        _ => crate::utils::ordering_unreachable_unchecked(order),
+                        _ => crate::utils::release_unreachable_unchecked(),
                     }
                 }
             }
@@ -108,7 +108,7 @@ macro_rules! atomic_load_store {
                                 options(nostack),
                             );
                         }
-                        _ => crate::utils::ordering_unreachable_unchecked(order),
+                        _ => crate::utils::release_unreachable_unchecked(),
                     }
                 }
             }
@@ -119,7 +119,7 @@ macro_rules! atomic_load_store {
 macro_rules! atomic {
     ($int_type:ident, $asm_suffix:tt) => {
         atomic_load_store!($int_type, $asm_suffix);
-        #[cfg(any(target_feature_a, target_feature = "a"))]
+        #[cfg(any(target_feature = "a", atomic_maybe_uninit_target_feature_a))]
         impl AtomicSwap for $int_type {
             #[inline]
             unsafe fn atomic_swap(
@@ -158,7 +158,7 @@ macro_rules! atomic {
                         Ordering::Release => atomic_swap!(".rl"),
                         // AcqRel and SeqCst swaps are equivalent.
                         Ordering::AcqRel | Ordering::SeqCst => atomic_swap!(".aqrl"),
-                        _ => crate::utils::ordering_unreachable_unchecked(order),
+                        _ => crate::utils::release_unreachable_unchecked(),
                     }
                 }
             }
